==> sqlitestudio-3.1.1.tar.gz: SQLiteStudio3/sqlitestudio/translations/sqlitestudio_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>QObject</name>
    <message>
        <source>GUI interface to SQLiteStudio, a SQLite manager.</source>
        <translation>Interfejs graficzny dla SQLiteStudio, menadżera SQLite.</translation>
    </message>
    <message>
        <source>Enables debug messages in console (accessible with F12).</source>
        <translation>Włącza wiadomości debugujące w konsoli (dostępnej przez F12).</translation>
    </message>
    <message>
        <source>Redirects debug messages into standard output (forces debug mode).</source>
        <translation>Przekierowuje wiadomości debugujące na standardowe wyjście (wymusza tryb debugujący).</translation>
    </message>
    <message>
        <source>Enables Lemon parser debug messages for SQL code assistant.</source>
        <translation>Włącza wiadomości debugujące analizatora Lemon dla asystenta kodu SQL.</translation>
    </message>
    <message>
        <source>Enables debugging of every single SQL query being sent to any database.</source>
        <translation>Włacza debugowanie każdego pojedynczego zapytania SQL, wykonywanego na dowolnej bazie danych.</translation>
    </message>
    <message>
        <source>Limits SQL query messages to only the given &lt;database&gt;.</source>
        <translation>Ogranicze wiadomości zapytań SQL do podanej &lt;bazy danych&gt;.</translation>
    </message>
    <message>
        <source>database</source>
        <translation>baza danych</translation>
    </message>
    <message>
        <source>file</source>
        <translation>plik</translation>
    </message>
    <message>
        <source>Database file to open</source>
        <translation>Baza danych do otwarcia</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <source>Lists plugins installed in the SQLiteStudio and quits.</source>
        <translation>Wypisuje listę zainstalowanych w SQLiteStudio wtyczek i wychodzi.</translation>
    </message>
    <message>
        <source>Redirects debug messages into given file (forces debug mode).</source>
        <translation>Przekierowuje wiadomości debugujące do danego pliku (wymusza tryb debugujący).</translation>
    </message>
    <message>
        <source>log file</source>
        <translation>plik logów</translation>
    </message>
    <message>
        <source>Enables debugging of SQLiteStudio&apos;s query executor.</source>
        <translation>Włącza debugowanie wykonawcy zapytań w SQLiteStudio.</translation>
    </message>
    <message>
        <source>Points to the master configuration file. Read manual at wiki page for more details.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SQLiteStudio settings file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> sqlitestudio-3.2.1.tar.gz: SQLiteStudio3/sqlitestudio/translations/sqlitestudio_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>QObject</name>
    <message>
        <source>GUI interface to SQLiteStudio, a SQLite manager.</source>
        <translation>Interfejs graficzny dla SQLiteStudio, menadżera SQLite.</translation>
    </message>
    <message>
        <source>Enables debug messages in console (accessible with F12).</source>
        <translation>Włącza wiadomości debugujące w konsoli (dostępnej przez F12).</translation>
    </message>
    <message>
        <source>Redirects debug messages into standard output (forces debug mode).</source>
        <translation>Przekierowuje wiadomości debugujące na standardowe wyjście (wymusza tryb debugujący).</translation>
    </message>
    <message>
        <source>Enables Lemon parser debug messages for SQL code assistant.</source>
        <translation>Włącza wiadomości debugujące analizatora Lemon dla asystenta kodu SQL.</translation>
    </message>
    <message>
        <source>Enables debugging of every single SQL query being sent to any database.</source>
        <translation>Włacza debugowanie każdego pojedynczego zapytania SQL, wykonywanego na dowolnej bazie danych.</translation>
    </message>
    <message>
        <source>Limits SQL query messages to only the given &lt;database&gt;.</source>
        <translation>Ogranicze wiadomości zapytań SQL do podanej &lt;bazy danych&gt;.</translation>
    </message>
    <message>
        <source>database</source>
        <translation>baza danych</translation>
    </message>
    <message>
        <source>file</source>
        <translation>plik</translation>
    </message>
    <message>
        <source>Database file to open</source>
        <translation>Baza danych do otwarcia</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="vanished">Błąd</translation>
    </message>
    <message>
        <source>Lists plugins installed in the SQLiteStudio and quits.</source>
        <translation>Wypisuje listę zainstalowanych w SQLiteStudio wtyczek i wychodzi.</translation>
    </message>
    <message>
        <source>Redirects debug messages into given file (forces debug mode).</source>
        <translation>Przekierowuje wiadomości debugujące do danego pliku (wymusza tryb debugujący).</translation>
    </message>
    <message>
        <source>log file</source>
        <translation>plik logów</translation>
    </message>
    <message>
        <source>Enables debugging of SQLiteStudio&apos;s query executor.</source>
        <translation>Włącza debugowanie wykonawcy zapytań w SQLiteStudio.</translation>
    </message>
    <message>
        <source>Points to the master configuration file. Read manual at wiki page for more details.</source>
        <translation>Wskazuje na główny plik konfiguracyjny. Więcej szczegółów w podręczniku na stronie wiki.</translation>
    </message>
    <message>
        <source>SQLiteStudio settings file</source>
        <translation>Plik ustawień SQLiteStudio</translation>
    </message>
</context>
</TS>
